==> python-gssapi-0.3.0.tar.gz: python-gssapi-0.3.0/gssapi/__init__.py <==
from __future__ import absolute_import

from .creds import BaseCredential, Credential
from .ctx import Context, InitContext, AcceptContext
from .error import GSSException, GSSCException
from .headers.gssapi_h import (
    GSS_C_DELEG_FLAG as C_DELEG_FLAG,
    GSS_C_MUTUAL_FLAG as C_MUTUAL_FLAG,
    GSS_C_REPLAY_FLAG as C_REPLAY_FLAG,
    GSS_C_SEQUENCE_FLAG as C_SEQUENCE_FLAG,
    GSS_C_CONF_FLAG as C_CONF_FLAG,
    GSS_C_INTEG_FLAG as C_INTEG_FLAG,
    GSS_C_ANON_FLAG as C_ANON_FLAG,
    GSS_C_PROT_READY_FLAG as C_PROT_READY_FLAG,
    GSS_C_TRANS_FLAG as C_TRANS_FLAG,
    GSS_C_DELEG_POLICY_FLAG as C_DELEG_POLICY_FLAG,
    GSS_C_BOTH as C_BOTH,
    GSS_C_INITIATE as C_INITIATE,
    GSS_C_ACCEPT as C_ACCEPT,
    GSS_C_NT_USER_NAME as C_NT_USER_NAME,
    GSS_C_NT_MACHINE_UID_NAME as C_NT_MACHINE_UID_NAME,
    GSS_C_NT_STRING_UID_NAME as C_NT_STRING_UID_NAME,
    GSS_C_NT_HOSTBASED_SERVICE as C_NT_HOSTBASED_SERVICE,
    GSS_C_NT_ANONYMOUS as C_NT_ANONYMOUS,
    GSS_C_NT_EXPORT_NAME as C_NT_EXPORT_NAME,
    GSS_S_COMPLETE as S_COMPLETE,
    GSS_S_CALL_INACCESSIBLE_READ as S_CALL_INACCESSIBLE_READ,
    GSS_S_CALL_INACCESSIBLE_WRITE as S_CALL_INACCESSIBLE_WRITE,
    GSS_S_CALL_BAD_STRUCTURE as S_CALL_BAD_STRUCTURE,
    GSS_S_BAD_MECH as S_BAD_MECH,
    GSS_S_BAD_NAME as S_BAD_NAME,
    GSS_S_BAD_NAMETYPE as S_BAD_NAMETYPE,
    GSS_S_BAD_BINDINGS as S_BAD_BINDINGS,
    GSS_S_BAD_STATUS as S_BAD_STATUS,
    GSS_S_BAD_SIG as S_BAD_SIG,
    GSS_S_NO_CRED as S_NO_CRED,
    GSS_S_NO_CONTEXT as S_NO_CONTEXT,
    GSS_S_DEFECTIVE_TOKEN as S_DEFECTIVE_TOKEN,
    GSS_S_DEFECTIVE_CREDENTIAL as S_DEFECTIVE_CREDENTIAL,
    GSS_S_CREDENTIALS_EXPIRED as S_CREDENTIALS_EXPIRED,
    GSS_S_CONTEXT_EXPIRED as S_CONTEXT_EXPIRED,
    GSS_S_FAILURE as S_FAILURE,
    GSS_S_BAD_QOP as S_BAD_QOP,
    GSS_S_UNAUTHORIZED as S_UNAUTHORIZED,
    GSS_S_UNAVAILABLE as S_UNAVAILABLE,
    GSS_S_DUPLICATE_ELEMENT as S_DUPLICATE_ELEMENT,
    GSS_S_NAME_NOT_MN as S_NAME_NOT_MN,
    GSS_S_CONTINUE_NEEDED as S_CONTINUE_NEEDED,
    GSS_S_DUPLICATE_TOKEN as S_DUPLICATE_TOKEN,
    GSS_S_OLD_TOKEN as S_OLD_TOKEN,
    GSS_S_UNSEQ_TOKEN as S_UNSEQ_TOKEN,
    GSS_S_GAP_TOKEN as S_GAP_TOKEN,
    GSS_S_CRED_UNAVAIL as S_CRED_UNAVAIL,
)
from .names import Name, BaseName, MechName
from .oids import OID, OIDSet, MutableOIDSet, get_all_mechs

==> python-gssapi-0.4.0.tar.gz: python-gssapi-0.4.0/gssapi/__init__.py <==
from __future__ import absolute_import

from .headers.gssapi_h import (
    GSS_C_DELEG_FLAG as C_DELEG_FLAG,
    GSS_C_MUTUAL_FLAG as C_MUTUAL_FLAG,
    GSS_C_REPLAY_FLAG as C_REPLAY_FLAG,
    GSS_C_SEQUENCE_FLAG as C_SEQUENCE_FLAG,
    GSS_C_CONF_FLAG as C_CONF_FLAG,
    GSS_C_INTEG_FLAG as C_INTEG_FLAG,
    GSS_C_ANON_FLAG as C_ANON_FLAG,
    GSS_C_PROT_READY_FLAG as C_PROT_READY_FLAG,
    GSS_C_TRANS_FLAG as C_TRANS_FLAG,
    GSS_C_DELEG_POLICY_FLAG as C_DELEG_POLICY_FLAG,
    GSS_C_BOTH as C_BOTH,
    GSS_C_INITIATE as C_INITIATE,
    GSS_C_ACCEPT as C_ACCEPT,
    GSS_C_INDEFINITE as C_INDEFINITE,
    GSS_C_NT_USER_NAME as C_NT_USER_NAME,
    GSS_C_NT_MACHINE_UID_NAME as C_NT_MACHINE_UID_NAME,
    GSS_C_NT_STRING_UID_NAME as C_NT_STRING_UID_NAME,
    GSS_C_NT_HOSTBASED_SERVICE as C_NT_HOSTBASED_SERVICE,
    GSS_C_NT_ANONYMOUS as C_NT_ANONYMOUS,
    GSS_C_NT_EXPORT_NAME as C_NT_EXPORT_NAME,
    GSS_S_COMPLETE as S_COMPLETE,
    GSS_S_CALL_INACCESSIBLE_READ as S_CALL_INACCESSIBLE_READ,
    GSS_S_CALL_INACCESSIBLE_WRITE as S_CALL_INACCESSIBLE_WRITE,
    GSS_S_CALL_BAD_STRUCTURE as S_CALL_BAD_STRUCTURE,
    GSS_S_BAD_MECH as S_BAD_MECH,
    GSS_S_BAD_NAME as S_BAD_NAME,
    GSS_S_BAD_NAMETYPE as S_BAD_NAMETYPE,
    GSS_S_BAD_BINDINGS as S_BAD_BINDINGS,
    GSS_S_BAD_STATUS as S_BAD_STATUS,
    GSS_S_BAD_SIG as S_BAD_SIG,
    GSS_S_NO_CRED as S_NO_CRED,
    GSS_S_NO_CONTEXT as S_NO_CONTEXT,
    GSS_S_DEFECTIVE_TOKEN as S_DEFECTIVE_TOKEN,
    GSS_S_DEFECTIVE_CREDENTIAL as S_DEFECTIVE_CREDENTIAL,
    GSS_S_CREDENTIALS_EXPIRED as S_CREDENTIALS_EXPIRED,
    GSS_S_CONTEXT_EXPIRED as S_CONTEXT_EXPIRED,
    GSS_S_FAILURE as S_FAILURE,
    GSS_S_BAD_QOP as S_BAD_QOP,
    GSS_S_UNAUTHORIZED as S_UNAUTHORIZED,
    GSS_S_UNAVAILABLE as S_UNAVAILABLE,
    GSS_S_DUPLICATE_ELEMENT as S_DUPLICATE_ELEMENT,
    GSS_S_NAME_NOT_MN as S_NAME_NOT_MN,
    GSS_S_CONTINUE_NEEDED as S_CONTINUE_NEEDED,
    GSS_S_DUPLICATE_TOKEN as S_DUPLICATE_TOKEN,
    GSS_S_OLD_TOKEN as S_OLD_TOKEN,
    GSS_S_UNSEQ_TOKEN as S_UNSEQ_TOKEN,
    GSS_S_GAP_TOKEN as S_GAP_TOKEN,
    GSS_S_CRED_UNAVAIL as S_CRED_UNAVAIL,
)
from .creds import Credential
from .ctx import Context, InitContext, AcceptContext
from .error import GSSException, GSSCException
from .names import Name, MechName
from .oids import OID, OIDSet, MutableOIDSet, get_all_mechs
